/*
 * Copyright (c) 2021 Nordic Semiconductor ASA
 * SPDX-License-Identifier: Apache-2.0
 */

#include <zephyr/kernel.h>
#include <zephyr/drivers/sensor.h>
#include <zephyr/drivers/gpio.h>
#include <zephyr/device.h>
#include <zephyr/drivers/gnss.h>
#include <zephyr/logging/log.h>


#include <zephyr/usb/usb_device.h>
#include <zephyr/usb/usbd.h>
#include <zephyr/drivers/uart.h>

BUILD_ASSERT(DT_NODE_HAS_COMPAT(DT_CHOSEN(zephyr_console), zephyr_cdc_acm_uart),
	     "Console device is not ACM CDC UART device");


LOG_MODULE_REGISTER(main, CONFIG_APP_LOG_LEVEL);


static const struct gpio_dt_spec good_led = GPIO_DT_SPEC_GET(DT_NODELABEL(good_led), gpios);
static const struct gpio_dt_spec fault_led = GPIO_DT_SPEC_GET(DT_NODELABEL(fault_led), gpios);
static const struct gpio_dt_spec status_0_led = GPIO_DT_SPEC_GET(DT_NODELABEL(status_led0), gpios);
static const struct gpio_dt_spec status_1_led = GPIO_DT_SPEC_GET(DT_NODELABEL(status_led1), gpios);
static const struct gpio_dt_spec status_2_led = GPIO_DT_SPEC_GET(DT_NODELABEL(status_led2), gpios);
static const struct gpio_dt_spec status_3_led = GPIO_DT_SPEC_GET(DT_NODELABEL(status_led3), gpios);
static const struct gpio_dt_spec gps_en = GPIO_DT_SPEC_GET(DT_NODELABEL(gps_en), gpios);



int main(void)
{
	int ret;

	LOG_INF("Telem3 Bootup sequence...");

	if (!gpio_is_ready_dt(&good_led)) {
		return 0;
	}

	ret = gpio_pin_configure_dt(&good_led, GPIO_OUTPUT_ACTIVE);
	ret |= gpio_pin_configure_dt(&fault_led, GPIO_OUTPUT_ACTIVE);
	ret |= gpio_pin_configure_dt(&status_0_led, GPIO_OUTPUT_ACTIVE);
	ret |= gpio_pin_configure_dt(&status_1_led, GPIO_OUTPUT_ACTIVE);
	ret |= gpio_pin_configure_dt(&status_2_led, GPIO_OUTPUT_ACTIVE);
	ret |= gpio_pin_configure_dt(&status_3_led, GPIO_OUTPUT_ACTIVE);
	ret |= gpio_pin_configure_dt(&gps_en, GPIO_OUTPUT_ACTIVE);
	if (ret < 0) {
		return 0;
	}

	gpio_pin_set_dt(&good_led, 0);
	gpio_pin_set_dt(&fault_led, 0);
	gpio_pin_set_dt(&status_0_led, 0);
	gpio_pin_set_dt(&status_1_led, 0);
	gpio_pin_set_dt(&status_2_led, 0);
	gpio_pin_set_dt(&status_3_led, 0);
	gpio_pin_set_dt(&gps_en, 0); // enable gps

	LOG_DBG("Init complete");
	while (1) {
		gpio_pin_toggle_dt(&fault_led);
		k_sleep(K_MSEC(500));
	}

	return 0;
}

